# Generated by Django 3.0.5 on 2020-08-22 15:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('csp_observer', '0010_auto_20200822_1446'),
    ]

    operations = [
        migrations.RenameField(
            model_name='csprule',
            old_name='description',
            new_name='short_description',
        ),
        migrations.AddField(
            model_name='csprule',
            name='long_description',
            field=models.TextField(blank=True, null=True),
        ),
    ]
