# Generated by Django 3.0.5 on 2020-06-18 12:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('csp_observer', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CspRule',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('blocked_url', models.CharField(blank=True, max_length=255, null=True)),
                ('effective_directive', models.CharField(blank=True, max_length=255, null=True)),
                ('ignore', models.BooleanField(default=False)),
                ('title', models.CharField(blank=True, max_length=255, null=True)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.AddField(
            model_name='cspreport',
            name='matching_rules',
            field=models.ManyToManyField(blank=True, to='csp_observer.CspRule'),
        ),
    ]
