# Generated by Django 3.0.5 on 2020-05-29 08:26

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Session',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('user_agent', models.CharField(max_length=255)),
                ('anonymized_ip', models.CharField(max_length=255)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.CreateModel(
            name='CspReport',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('document_url', models.CharField(max_length=255)),
                ('referrer', models.CharField(blank=True, max_length=255, null=True)),
                ('blocked_url', models.CharField(blank=True, max_length=255, null=True)),
                ('effective_directive', models.CharField(max_length=255)),
                ('original_policy', models.CharField(max_length=255)),
                ('source_file', models.CharField(blank=True, max_length=255, null=True)),
                ('sample', models.CharField(blank=True, max_length=255, null=True)),
                ('disposition', models.CharField(max_length=255)),
                ('status_code', models.IntegerField(blank=True, null=True)),
                ('line_number', models.IntegerField(blank=True, null=True)),
                ('column_number', models.IntegerField(blank=True, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('session', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='csp_observer.Session')),
            ],
        ),
    ]
