# Generated by Django 3.0.5 on 2020-08-19 19:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('csp_observer', '0007_config'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Config',
            new_name='StoredConfig',
        ),
    ]
