# Generated by Django 3.0.5 on 2020-08-19 18:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('csp_observer', '0003_auto_20200703_1300'),
    ]

    operations = [
        migrations.AddField(
            model_name='csprule',
            name='is_custom_rule',
            field=models.BooleanField(default=True),
        ),
    ]
