# Generated by Django 3.0.5 on 2020-08-22 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('csp_observer', '0009_auto_20200821_0838'),
    ]

    operations = [
        migrations.AddField(
            model_name='csprule',
            name='global_id',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='storedconfig',
            name='value',
            field=models.TextField(blank=True, null=True),
        ),
    ]
