{% extends 'cspo_base.html' %}
{% load static %}

{% block title %}Privacy Policy{% endblock title %}

{% block content %}
<div class="container">
    <h1>Privacy Policy</h1>
    <h2>Placeholder Page</h2>
    <p>Lorem ipsum dolor sit amet consectetur adipisicing elit. Voluptatibus alias fugiat, porro nobis id ex est nam voluptate officia, laborum fuga eum aperiam ea facilis mollitia neque accusantium nihil qui.</p>
</div>
{% endblock content %}
