#cspo-clientui {
  font-family: BlinkMacSystemFont,-apple-system,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,Helvetica,Arial,sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  color: #212529;
  position: fixed;
  bottom: 10px;
  right: 10px;
  max-width: 300px;
  background-color: #fff;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  box-shadow: 3px 3px 15px rgba(0, 0, 0, 0.2);
  opacity: 0.5;
  transition: opacity 0.15s;
  cursor: default;
  overflow: hidden;
  transition: transition 0.2s;
  transition: margin 0.2s;
  opacity: 0;
  margin-bottom: -1000px;
}

#cspo-clientui * {
  box-sizing: border-box;
}

#cspo-clientui button, #cspo-clientui select {
  text-transform: none;
}
#cspo-clientui button, #cspo-clientui input {
  overflow: visible;
}
#cspo-clientui button, #cspo-clientui input, #cspo-clientui optgroup, #cspo-clientui select, #cspo-clientui textarea {
  margin: 0;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}
#cspo-clientui button {
  border-radius: 0;
}

#cspo-clientui p {
  margin-top: 0;
  margin-bottom: 1rem;
}

#cspo-clientui.visible {
  opacity: 0.5;
  margin-bottom: 0;
  bottom: 10px;
}

#cspo-clientui.visible:hover {
  opacity: 1;
  top: inherit;
  bottom: 10px;
}

.clientui-header {
  background-color: #f5f5f5;
  border-bottom: 1px solid rgba(0, 0, 0, 0.2);
  height: 40px;
}

.clientui-header>.clientui-title {
  line-height: 40px;
  margin-left: 10px;
}

.clientui-header>.close {
  width: 20px;
  height: 20px;
  position: absolute;
  right: 10px;
  top: 5px;
  outline: none;
  cursor: pointer;
  padding: 0;
  background-color: transparent;
  border: 0;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  float: right;
  font-size: 1.5rem;
  font-weight: 700;
  line-height: 1;
  color: #000;
  text-shadow: 0 1px 0 #fff;
  opacity: .5;
}

.clientui-body {
  padding: 10px;
}

.clientui-body .status {
  width: 100%;
  position: relative;
  display: flex;
  flex-direction: row;
  justify-content: center;
}

.clientui-body .status .icon {
  height: 50px;
  width: 50px;
}

.clientui-body .status .icon .result-icon {
  position: absolute;
  top: 5px;
  left: 5px;
  height: 40px;
  width: 40px;
  opacity: 0;
  transition: opacity .6s;
}

.clientui-body .status .icon .result-icon.visible {
  opacity: 1;
}

#cspo-icon-check {
  filter: invert(65%) sepia(50%) saturate(4240%) hue-rotate(130deg) brightness(100%) contrast(101%);
}

#cspo-icon-alert {
  filter: invert(50%) sepia(92%) saturate(5424%) hue-rotate(329deg) brightness(104%) contrast(101%);
}

.clientui-body .status .content {
  margin-left: 10px;
}

#cspo-status-message {
  margin: 0;
  font-size: 1rem;
  line-height: 50px;
}

.clientui-body .spoiler {
  margin-top: 10px;
  padding-top: 10px;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  overflow: hidden;
  transition: margin 0.2s;
}

.clientui-body .spoiler.hidden {
  margin-top: 0;
  border-top: 0;
  margin-bottom: -120px;
}

.help {
  font-size: 0.75rem;
}

#cspo-icon {
  float: left;
  margin-right: 5px;
}

.spinner {
  width: 40px;
  height: 40px;
  position: relative;
}

.double-bounce1, .double-bounce2 {
  width: 100%;
  height: 100%;
  border-radius: 50%;
  background-color: #00d1b2;
  opacity: 0.6;
  position: absolute;
  top: 0;
  left: 0;
  -webkit-animation: sk-bounce 2.0s infinite ease-in-out;
  animation: sk-bounce 2.0s infinite ease-in-out;
}

.double-bounce2 {
  -webkit-animation-delay: -1.0s;
  animation-delay: -1.0s;
}

@-webkit-keyframes sk-bounce {
  0%, 100% {
    -webkit-transform: scale(0.0)
  }
  50% {
    -webkit-transform: scale(1.0)
  }
}

@keyframes sk-bounce {
  0%, 100% {
    transform: scale(0.0);
    -webkit-transform: scale(0.0);
  }
  50% {
    transform: scale(1.0);
    -webkit-transform: scale(1.0);
  }
}