# Generated by Django 3.0.5 on 2020-08-19 19:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('csp_observer', '0005_auto_20200819_1908'),
    ]

    operations = [
        migrations.AlterField(
            model_name='csprule',
            name='cause',
            field=models.CharField(choices=[('extension', 'Browser Extension'), ('browser', 'Web Browser'), ('malware', 'Malware'), ('other', 'Other')], default='other', max_length=255),
        ),
    ]
